MyoroCountryRegionCityDropdownStyle class

Implementers
Annotations

Constructors

MyoroCountryRegionCityDropdownStyle({double? spacing})
Default constructor.
const
MyoroCountryRegionCityDropdownStyle.fake()
Fake constructor.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self MyoroCountryRegionCityDropdownStyle
no setterinherited
spacing double?
Spacing between dropdowns.
final

Methods

copyWith({double? spacing, bool spacingProvided = true}) MyoroCountryRegionCityDropdownStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited