MyoroCurrencyInputState class

Constructors

MyoroCurrencyInputState(double min, double? max, int decimalPlaces, MyoroCurrencyEnum currency, bool canChangeCurrency, bool autofocus, MyoroCurrencyInputOnChanged onChanged, FocusNode? focusNode, TextEditingController? controller, MyoroCurrencyInputOnFieldSubmitted? onFieldSubmitted)
Default constructor.

Properties

autofocus bool
Whether the input should autofocus.
getter/setter pair
canChangeCurrency bool
If the user can select another currency.
getter/setter pair
controller TextEditingController
_controller getter.
getter/setter pair
decimalPlaces int
Decimal places.
getter/setter pair
focusNode FocusNode
_focusNode getter.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
max double?
Max value.
getter/setter pair
min double
Min value.
getter/setter pair
onChanged MyoroCurrencyInputOnChanged
On changed.
getter/setter pair
onFieldSubmitted MyoroCurrencyInputOnFieldSubmitted?
On field submitted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCurrency MyoroCurrencyEnum
Getter of _selectedCurrencyController's value.
getter/setter pair
selectedCurrencyController ValueNotifier<MyoroCurrencyEnum>
_selectedCurrencyController getter.
no setter
showing bool
Getter of _showingController's value.
getter/setter pair
showingController ValueNotifier<bool>
_showingController getter.
no setter

Methods

dispose() → void
Dispose function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited