MyoroFeedbackThemeExtension class

Inheritance
Implemented types
Annotations

Constructors

MyoroFeedbackThemeExtension({double? spacing, MyoroIconStyle? iconStyle, MyoroTextStyle? titleTextStyle, MyoroTextStyle? subtitleTextStyle})
Default constructor.
const
MyoroFeedbackThemeExtension.builder(TextTheme textTheme)
MyoroFeedbackThemeExtension.fake()
Fake constructor.

Properties

hashCode int
The hash code for this object.
no setterinherited
iconStyle MyoroIconStyle?
Size of the icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self MyoroFeedbackThemeExtension
no setterinherited
spacing double?
Spacing between the icon/title/subtitle and the action button.
final
subtitleTextStyle MyoroTextStyle?
TextStyle of the subtitle.
final
titleTextStyle MyoroTextStyle?
TextStyle of the title.
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({double? spacing, bool spacingProvided = true, MyoroIconStyle? iconStyle, bool iconStyleProvided = true, MyoroTextStyle? titleTextStyle, bool titleTextStyleProvided = true, MyoroTextStyle? subtitleTextStyle, bool subtitleTextStyleProvided = true}) MyoroFeedbackThemeExtension
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
inherited
lerp(covariant MyoroFeedbackThemeExtension? other, double t) MyoroFeedbackThemeExtension
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited