MyoroFilePickerViewModel class final

View model of MyoroFilePicker.

Constructors

MyoroFilePickerViewModel(String? title, MyoroFilePickerFileTypeEnum fileType, List<String> allowedExtensions, MyoroFilePickerOnChanged onChanged)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state MyoroFilePickerState
_state getter.
no setter

Methods

dispose() → void
Dispose function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openPicker() Future<void>
Opens the file picker.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited