MyoroTableState<T> class final

Constructors

MyoroTableState({required MyoroTableConfigurationRequest<T> request, required List<MyoroTableColumn> columns, required MyoroTableConfigurationRowBuilder<T> rowBuilder})
Creates a new instance of MyoroTableState.

Properties

columns List<MyoroTableColumn>
_columns getter.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
itemsRequest MyoroRequest<Set<T>>
_itemsRequestController getter.
no setter
itemsRequestController MyoroRequestController<Set<T>>
_itemsRequestController getter.
no setter
request MyoroTableConfigurationRequest<T>
_request getter.
getter/setter pair
rowBuilder MyoroTableConfigurationRowBuilder<T>
_rowBuilder getter.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleColumnKeys List<GlobalKey<State<StatefulWidget>>>
_titleColumnKeys getter.
no setter
titleColumnKeyWidthsController ValueNotifier<List<double>>
_titleColumnKeyWidthsController getter.
no setter

Methods

dispose() → void
Dispose function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited