MyoroTooltipStyle class

Style model of MyoroTooltip.

Implementers
Annotations

Constructors

MyoroTooltipStyle({EdgeInsets? margin})
Default constructor.
const
MyoroTooltipStyle.fake()
Fake constructor.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
Tooltip.margin.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self MyoroTooltipStyle
no setterinherited

Methods

copyWith({EdgeInsets? margin, bool marginProvided = true}) MyoroTooltipStyle
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(MyoroTooltipStyle? a, MyoroTooltipStyle? b, double t) MyoroTooltipStyle
Lerp function.