MyoroBasicDividerStyle class
Style model of MyoroBasicDivider.
- Implementers
- Annotations
-
- @immutable
- @myoroModel
Constructors
- MyoroBasicDividerStyle({Color? color, double? shortValue, double? longValue})
-
Default constructor.
const
- MyoroBasicDividerStyle.fake()
-
Fake constructor.
factory
Properties
- color → Color?
-
Color of the
MyoroDivider.final - hashCode → int
-
The hash code for this object.
no setterinherited
- longValue → double?
-
Height of the divider. double.infinity by default.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- self → MyoroBasicDividerStyle
-
no setterinherited
- shortValue → double?
-
Width of the divider. kMyoroBorderWidth by default.
final
Methods
-
copyWith(
{Color? color, bool colorProvided = true, double? shortValue, bool shortValueProvided = true, double? longValue, bool longValueProvided = true}) → MyoroBasicDividerStyle -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
MyoroBasicDividerStyle? a, MyoroBasicDividerStyle? b, double t) → MyoroBasicDividerStyle - Lerp function.