MyoroCarousel class
Slider carousel.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MyoroCarousel
Constructors
-
MyoroCarousel({Key? key, MyoroCarouselStyle style = const MyoroCarouselStyle(), CarouselSliderController? controller, Axis direction = directionDefaultValue, bool displayTraversalButtons = displayTraversalButtonsDefaultValue, int initialItem = initialItemDefaultValue, bool autoplay = autoplayDefaultValue, Duration autoplayIntervalDuration = autoplayIntervalDurationDefaultValue, required List<
Widget> items}) -
const
Properties
- autoplay → bool
-
If the carousel autoslides items.
final
- autoplayIntervalDuration → Duration
-
autoplay interval duration.
final
- controller → CarouselSliderController?
-
Controller.
final
- direction → Axis
-
Direction that the carousel is sliding in.
final
- displayTraversalButtons → bool
-
Display buttons to traverse items.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialItem → int
-
Initial item from
slidesstarting in the carousel.final -
items
→ List<
Widget> -
Slides of the carousel.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → MyoroCarouselStyle
-
ThemeExtension
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- autoplayDefaultValue → const bool
- Default value for autoplay.
- autoplayIntervalDurationDefaultValue → const Duration
- Default value for autoplayIntervalDuration.
- directionDefaultValue → const Axis
- Default value for direction.
- displayTraversalButtonsDefaultValue → const bool
- Default value for displayTraversalButtons.
- initialItemDefaultValue → const int
- Default value for initialItem.