MyoroCurrencyInputViewModel class
View model of MyoroCurrencyInput.
Constructors
- MyoroCurrencyInputViewModel(double min, double? max, int decimalPlaces, MyoroCurrencyEnum currency, bool canChangeCurrency, bool autofocus, MyoroCurrencyInputOnChanged onChanged, FocusNode? focusNode, TextEditingController? controller, MyoroCurrencyInputOnFieldSubmitted? onFieldSubmitted)
- Default constructor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → MyoroCurrencyInputState
-
_stategetter.no setter
Methods
-
dispose(
) → void - Dispose function.
-
itemBuilder(
dynamic _, MyoroCurrencyEnum currency) → MyoroMenuItem - MyoroDropdown.itemBuilder
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toggleDropdown(
) → void - Toggles the dropdown.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited