MyoroFilePickerStyle class
Style model of MyoroFilePicker.
- Implementers
- Annotations
-
- @immutable
- @myoroModel
Constructors
- MyoroFilePickerStyle({double? spacing, MyoroTextStyle? textStyle})
-
Default constructor.
const
- MyoroFilePickerStyle.fake()
-
Fake constructor.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- self → MyoroFilePickerStyle
-
no setterinherited
- spacing → double?
-
Spacing between the selected file section text and the selection button.
final
- textStyle → MyoroTextStyle?
-
TextStyle of the text of the MyoroFilePicker.
final
Methods
-
copyWith(
{double? spacing, bool spacingProvided = true, MyoroTextStyle? textStyle, bool textStyleProvided = true}) → MyoroFilePickerStyle -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
MyoroFilePickerStyle? a, MyoroFilePickerStyle? b, double t) → MyoroFilePickerStyle - Lerp function.