MyoroScrollableState class sealed
State of MyoroScrollableViewModel.
- Implementers
Properties
- clipBehavior → Clip
-
Clip behavior.
final
- direction → Axis
-
Axis.
final
- displayEndingGradient ↔ bool
-
Getter of
_displayEndingGradientController's value.getter/setter pair -
displayEndingGradientController
→ ValueNotifier<
bool> -
_displayEndingGradientControllergetter.no setter - displayStartingGradient ↔ bool
-
Getter of
_displayStartingGradientController's value.getter/setter pair -
displayStartingGradientController
→ ValueNotifier<
bool> -
_displayStartingGradientControllergetter.no setter - dragStartBehavior → DragStartBehavior
-
Drag start behavior.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- physics → ScrollPhysics?
-
Physics.
final
- reverse → bool
-
Reversed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController ↔ ScrollController
-
ScrollController.
latefinal
- thumbVisibility → bool
-
Whether or not the scrollbar should always be shown when the scrollable is scrollable.
final
Methods
-
dispose(
) → void - Dispose function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited