MyoroTableState<T> class
final
State of MyoroTableViewModel.
Constructors
-
MyoroTableState({required MyoroTableConfigurationRequest<
T> request, required List<MyoroTableColumn> columns, required MyoroTableConfigurationRowBuilder<T> rowBuilder}) - Creates a new instance of MyoroTableState.
Properties
-
columns
↔ List<
MyoroTableColumn> -
_columnsgetter.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
itemsRequest
→ MyoroRequest<
Set< T> > -
_itemsRequestControllergetter.no setter -
itemsRequestController
→ MyoroRequestController<
Set< T> > -
_itemsRequestControllergetter.no setter -
request
↔ MyoroTableConfigurationRequest<
T> -
_requestgetter.getter/setter pair -
rowBuilder
↔ MyoroTableConfigurationRowBuilder<
T> -
_rowBuildergetter.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
titleColumnKeys
→ List<
GlobalKey< State< >StatefulWidget> > -
_titleColumnKeysgetter.no setter -
titleColumnKeyWidthsController
→ ValueNotifier<
List< double> > -
_titleColumnKeyWidthsControllergetter.no setter
Methods
-
dispose(
) → void - Dispose function.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited