MyoroTableThemeExtension class
- Inheritance
-
- Object
- ThemeExtension<
MyoroTableThemeExtension> - MyoroTableThemeExtension
- Implemented types
- Annotations
-
- @immutable
- @myoroThemeExtension
Constructors
- MyoroTableThemeExtension({Color? backgroundColor, TextStyle? columnTextStyle, double? columnSpacing, TextStyle? rowTextStyle, EdgeInsets? loaderEmptyMessageErrorMessagePadding, TextStyle? emptyMessageTextStyle, TextStyle? errorMessageTextStyle})
-
Default constructor.
const
- MyoroTableThemeExtension.builder(ColorScheme colorScheme, TextTheme textTheme)
- MyoroTableThemeExtension.fake()
- Fake constructor.
Properties
- backgroundColor → Color?
-
Background color of the table.
final
- columnSpacing → double?
-
Spacing between columns.
final
- columnTextStyle → TextStyle?
-
Default TextStyle of columns.
final
- emptyMessageTextStyle → TextStyle?
-
TextStyle of the empty message.
final
- errorMessageTextStyle → TextStyle?
-
TextStyle of the error message.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loaderEmptyMessageErrorMessagePadding → EdgeInsets?
-
EdgeInsets of the loader, empty message and error message.
final
- rowTextStyle → TextStyle?
-
Default TextStyle of rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- self → MyoroTableThemeExtension
-
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? backgroundColor, bool backgroundColorProvided = true, TextStyle? columnTextStyle, bool columnTextStyleProvided = true, double? columnSpacing, bool columnSpacingProvided = true, TextStyle? rowTextStyle, bool rowTextStyleProvided = true, EdgeInsets? loaderEmptyMessageErrorMessagePadding, bool loaderEmptyMessageErrorMessagePaddingProvided = true, TextStyle? emptyMessageTextStyle, bool emptyMessageTextStyleProvided = true, TextStyle? errorMessageTextStyle, bool errorMessageTextStyleProvided = true}) → MyoroTableThemeExtension -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
inherited
-
lerp(
covariant MyoroTableThemeExtension? other, double t) → MyoroTableThemeExtension -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited